@@ -1,7 +1,8 @@
 package BusyBird::Filter;
+use v5.8.0;
 use strict;
 use warnings;
-use Exporter qw(import);
+use Exporter 5.57 qw(import);
 use Carp;
 use Storable qw(dclone);
 
