@@ -1,7 +1,8 @@
 package BusyBird::SafeData;
+use v5.8.0;
 use strict;
 use warnings;
-use Exporter qw(import);
+use Exporter 5.57 qw(import);
 use Data::Diver ();
 
 our @EXPORT_OK = qw(safed);
